@@ -1,11 +1,12 @@
-c     *****************************************************************
-c     *                                                               *
-c     *  sparmr: read       sepics parameter
-c     *  sparmw  write                                                *
-c     *****************************************************************
-c
-c
+!     *****************************************************************
+!     *                                                               *
+!     *  sparmr: read       sepics parameter
+!     *  sparmw  write                                                *
+!     *****************************************************************
+!
+!
        subroutine sparmr(dsn)
+       use modShiftInciPos, only: ShiftInciPos
        implicit none
 #include  "ZsepManager.h"
 #include  "ZepPos.h"
@@ -25,27 +26,27 @@ c
            hookic = 0
            hookrc = 0
                                                       
-c
+!
 
            call copenf(iowk, dsn, icon)
            if(icon .ne. 0) then
               call cerrorMsg(' file not exist', 1)
               call cerrorMsg(dsn, 0)
            endif
-c               skip separator
+!               skip separator
            call afsep(iowk)
-c               read each item
+!               read each item
            do while ( epgetParmN(iowk, vname, vvalue) )
               if( vname .eq. 'BaseTime' ) then
                  call arprmr(vvalue, BaseTime)
               elseif( vname .eq. 'CosNormal') then
                  call arprmm(vvalue, CosNormal)
               elseif( vname .eq. 'DCInpX') then
-                 call arprmr(vvalue, DCInp.x)
+                 call arprmr(vvalue, DCInp%x)
               elseif( vname .eq. 'DCInpY') then
-                 call arprmr(vvalue, DCInp.y)
+                 call arprmr(vvalue, DCInp%y)
               elseif( vname .eq. 'DCInpZ') then
-                 call arprmr(vvalue, DCInp.z)
+                 call arprmr(vvalue, DCInp%z)
               elseif( vname .eq. 'DeadLine') then
                  call arprmc(vvalue, DeadLine)
               elseif( vname .eq. 'E0Max') then
@@ -68,12 +69,14 @@ c               read each item
                  call arprmc(vvalue, PrimaryFile)
               elseif( vname .eq. 'ProfR') then
                  call arprmr(vvalue, ProfR)
+              elseif( vname == 'ShiftInciPos') then
+                 call arprmc(vvalue, ShiftInciPos)
               elseif( vname .eq. 'Xinp') then
-                 call arprmr(vvalue, PosInp.x)
+                 call arprmr(vvalue, PosInp%x)
               elseif( vname .eq. 'Yinp') then
-                 call arprmr(vvalue, PosInp.y)
+                 call arprmr(vvalue, PosInp%y)
               elseif( vname .eq. 'Zinp') then
-                 call arprmr(vvalue, PosInp.z)
+                 call arprmr(vvalue, PosInp%z)
               elseif( vname .eq. 'LogIr' ) then
                  call arprml(vvalue,LogIr) 
               elseif( vname .eq. 'Xrange' ) then
@@ -169,9 +172,9 @@ c               read each item
            write(io,*)'----------------------'
            call awprmr(io,'BaseTime', BaseTime)
            call awprmm(io,'CosNormal', CosNormal)
-           call awprmr(io,'DCInpX', DCInp.x)
-           call awprmr(io,'DCInpY', DCInp.y)
-           call awprmr(io,'DCInpZ', DCInp.z)
+           call awprmr(io,'DCInpX', DCInp%x)
+           call awprmr(io,'DCInpY', DCInp%y)
+           call awprmr(io,'DCInpZ', DCInp%z)
            call awprmc(io,'DeadLine', DeadLine)
            call awprmr(io,'E0Max', E0Max)
            call awprmr(io,'Hwhm', Hwhm)
@@ -183,9 +186,10 @@ c               read each item
            call awprmi(io,'Nevent',Nevent)
            call awprmc(io, 'PrimaryFile', PrimaryFile)
            call awprmr(io,'ProfR', ProfR)
-           call awprmr(io,'Xinp', PosInp.x)
-           call awprmr(io,'Yinp', PosInp.y)
-           call awprmr(io,'Zinp', PosInp.z)
+           call awprmr(io,'ShiftInciPos', ShiftInciPos)
+           call awprmr(io,'Xinp', PosInp%x)
+           call awprmr(io,'Yinp', PosInp%y)
+           call awprmr(io,'Zinp', PosInp%z)
            call awprml(io,'LogIr', LogIr)
            call awprmm(io,'Xrange', Xrange)
            call awprmm(io,'Yrange', Yrange)
