@@ -4,7 +4,8 @@
 #include "Zmedia.h"
 
       character(*),intent(in)::file ! path to the basic media file
-      record /epmedia/ media  ! ouput. media data is read
+              ! may be Air*0.01 type
+      type(epmedia),intent(out)::  media  !  media data is read
 
 !          initialization before using epBrgenex, epBrgene
 !                                      epPrgenex, epPrgene
@@ -17,26 +18,35 @@
 !
       integer i, icon
       integer,parameter::io=5
+      real(4):: rhoc
+      character(:),allocatable:: tfile
 
-      call copenf(io, file, icon)
+      tfile=file  
+      call epgetRhoc(file, tfile, rhoc)  !../Air*0.01==>../Air and rhoc  
+      call copenf(io, tfile, icon)
       if(icon /= 0 ) then
-         write(0,*) 'file=',trim(file), ' could not  be opend'
+         write(0,*) 'tfile=',trim(tfile), '---- could not  be opend---'
          stop
       endif
 
       write(0,*) ' entering epReadMTbl'
       call epReadMTbl(io, media)
       close(io)
+!
+!     media%rho = media%rho*rhoc  ! this is easy way but
+! in actual M.C where the same media may be
+!           used with diff. rhoc, N.G      
+      media%rhoc =rhoc
 
 
       write(0,*) ' entering epGetEffZA'
       call epGetEffZA(media)
       write(0,*) ' entering epSetSTblCns'
-      call epSetSTblCns(media, media.cnst)
+      call epSetSTblCns(media, media%cnst)
 !          init for Seltzer function
       write(0,*) ' entering epZforSelt'
-      do i = 1, media.noOfElem
-         call epZforSeltz(i, media.elem(i).Z)
+      do i = 1, media%noOfElem
+         call epZforSeltz(i, media%elem(i)%Z)
       enddo
 
       write(0,*) ' bpsetmedi '
