@@ -1,5 +1,9 @@
 #include "ZsubstRec.h"
 #include "Zepcondc.h"
+      module moddebug
+      logical,save:: debugmodeON=.false.
+      logical,save:: firstdebug=.true.
+      end module moddebug
 !        epifCross is changed radically.
 !        epbndry; icon is changed to get el in real*8
 !        *********************************************************
@@ -322,7 +326,10 @@
 
       end
 
-       subroutine epfl1
+      subroutine epfl1
+!!!!!
+      use moddebug
+!!!!!!!!!      
        implicit none
 !           follow 1 particle
 !              until current partile dies or all are put into stack.
@@ -336,9 +343,8 @@
       do while (.true.)
 !                current track is in  cTrack
 !          fix process and free path
-!          and compute tentative new pos.--> Move
+!     and compute tentative new pos.--> Move
          call epnewp(icon)
-
          if(icon .ne. 0) goto 100 ! abort is specified by the user
 !          energy loss count in user hook
 !         if(Det.cmp(Cn).CountDE .gt. 0 .and. >>>>>>>>>light
@@ -382,9 +388,8 @@
 
 !                 multiple scattering, magnetic deflection
 !                 electric deflection. 
-!                 if MCSmode, MCS will not be done inside
+!     if MCSmode, MCS will not be done inside
             call epdeflection(icon)  
-
          endif
 !              take trace info.
          call epTraceFE  ! v9.17
@@ -436,6 +441,9 @@
       use modepRange, only:       attenF
        use modMCScontrol
        use modV1ry
+!!!!!!!!
+       use moddebug
+!!!!!!!!       
       implicit none
 #include  "ZepManager.h"
 #include  "ZepTrackv.h"
@@ -466,7 +474,6 @@
 !       care.
 
       call epchckE0(cTrack, icon)  ! simple energy check
-
       if( icon /= 0 ) then
          if( ImperativeEmin .or. icon == -1 ) then
             Absorb = .true.
@@ -479,7 +486,7 @@
 !             energy is low, see if the range is < el
             call epGetRange(MediaNo, Media(MediaNo), cTrack%p,
      *                      Rgm, Rcm)
-            Absorb =  Rcm < lengthToB 
+            Absorb =  Rcm < lengthToB
             if( Absorb ) then
             !  current ptcl KE may be absorbed during path = Rcm
             !  suppose particle can run Rcm (for charge).
@@ -538,7 +545,7 @@
       if(cTrack%p%code .eq. kphoton) then
          call epprog  ! Move.proc, Move.dt fixed
       elseif(cTrack%p%code .eq. kelec) then
-         call epproe  ! Move.proc, Move.dt fixed
+         call epproe            ! Move.proc, Move.dt fixed
       elseif( cTrack%p%code > 0 ) then
          call epNonEleMag
 !>>>>>>>>>>>>>light
@@ -554,7 +561,6 @@
 !     *************** truncate if too long  **********************
 !              trancate if dt is too long (set Trunc=t/f)
       call eptrunc
-
       if( ActiveMCS == "El_hin") then
            ! fix MCSmode and change Move.dl, if needed 
          call epdoMixedMCS1
@@ -610,6 +616,10 @@
       end
 !        fix MCSmode and change Move.dl if needed.
       subroutine epdoMixedMCS1
+!!!!!!!
+      use moddebug
+!!!!!!!!!      
+      
       use modcMCS
       use modMCScontrol
       implicit none
@@ -659,6 +669,9 @@
 
 
       subroutine epdoMixedMCS2(icon)
+!!!!!!!!!!!1
+      use moddebug
+!!!!!!!!!!      
       use modMCScontrol 
       implicit none
 #include "ZepTrackv.h"
@@ -1052,6 +1065,10 @@
       end
 !     ******************
       subroutine epEloss
+      use modMCScontrol
+!!!!!!!!!
+      use moddebug
+!!!!!!!!!      
       use moddedx
       use modGUI
       implicit none
@@ -1252,12 +1269,29 @@
          Move%dl =min( dx * Media(MediaNo)%gtocm /
      *     Media(MediaNo)%rhoc, Move%dl)
          Move%dx = dx
-
+!!!!!!!!!!Jan. 2017.
+! in the case of El_hin, Move%dl is long (
+!     from previous hard cs point, while cTrack point is
+!     hinge point, so Moved point below could be outside
+!     of the prsent volume. Althouth the particle is already
+!     dead, in the next step, it is treated as if a live
+!     particle and the boundary is searched for. If the
+!     position is not in the true component, boundary seachh
+!     error happens. It can be recovered automatically,but
+!     if it happens > 10 times /event, stop is forced.
+!     To avoid such, we keep the moved particle position
+!     at the current hinge point. The energy loss is
+!     in the correct compoenent, so little difference
+!     of stopping point dosn't matter.
+         if(ActiveMCS == "El_hin") then
+            Move%dl=0.
+            MOve%dx =0.
+         endif
+!!!!!!!!!
          Move%Track%pos%x = cTrack%pos%x + Move%dl* cTrack%w%x 
          Move%Track%pos%y = cTrack%pos%y + Move%dl* cTrack%w%y
          Move%Track%pos%z = cTrack%pos%z + Move%dl* cTrack%w%z
       endif
-
       SumDe = SumDe + Move%dE
       end
 !      ****************************************
@@ -1370,6 +1404,9 @@
 !     *************
       subroutine  epproe
 !     *************
+!!!!!!!!!
+      use moddebug
+!!!!!!!!!      
       use modMCScontrol
       implicit none
 !
@@ -1412,7 +1449,6 @@
          endif
       endif
 
-
       if( doNewMCS ) then
          if( (Media(MediaNo)%name /= 'sp' ) .and.
      *       (Media(MediaNo)%name /= 'hollow')  ) then
@@ -1432,7 +1468,7 @@
       if( ActiveMCS == 'El_hin') then
              ! sample hard scattering  mfp g/cm2.
          call cgetLamh( KEeV, mfpHardgr)  ! mfp of hard cs
-                                  !  in g/cm2
+!  in g/cm2
          call rndc(u)
          lHardgr = -log(u)* mfpHardgr  ! g/cm2
          lHardrl =lHardgr / Media(MediaNo)%X0g    ! rl
@@ -1440,7 +1476,7 @@
           ! next is  cm length. this might  be used later for soft
           ! mcs treatment.
          lHardcm = lHardgr* Media(MediaNo)%gtocm
-     *             / Media(MediaNo)%rhoc
+     *        / Media(MediaNo)%rhoc
          if( lHardrl < t ) then
             Move%proc="hcs"  ! hard Coulomb scattring
             t = lHardrl
