@@ -1,6 +1,8 @@
       subroutine epprmr(dsn)
       use modV1ry
-       implicit none
+      use SampMolReducedA
+      use modMCSparam
+      implicit none
 #include  "ZepTrackp.h"
 #include  "ZepManager.h"
 !
@@ -111,6 +113,16 @@
                   else
                      call arprmi(vvalue, Moliere)
                   endif
+               elseif( vname == 'MCSmodel' ) then
+                  call arprmc(vvalue, MCSmodel)
+               elseif( vname == 'MCSdir' ) then
+                  call arprmc(vvalue, MCSdir)
+               elseif( vname == 'MCSparam' ) then
+                  call arprmc(vvalue, MCSparam)
+               elseif( vname == 'sbMin' ) then ! v9.201;don't use
+                  write(0,*)
+     *            'NOTE****: sbMin in epicsfile obsolete; not used'
+!                  call arprmr(vvalue, sbMin)
                elseif( vname .eq. 'Photo') then
                   call arprml(vvalue, Photo)
                elseif( vname .eq. 'RecoilKeMin') then
@@ -271,13 +283,20 @@
        subroutine  epcmp1
 !      ************
        use epModify
+       use SampMolReducedA
        implicit none
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
 #include "ZepManager.h"
 #include "Zmass.h"
 !             compute something using basic parameters
-!
+!              v 9.201
+       if( sbMin == 0. .and. Moliere == 1 ) then
+          sbMin=3.395d0
+       elseif(sbMin == 0. .and. Moliere == 2 ) then
+          sbMin=1.5d0
+       endif
+
        if(ALateCor .eq. 2 .or.
      *        ( ALateCor .eq. 1 .and.  Moliere == 0)) then
 !          angular latelaral correlation will be taken at
